summaryrefslogtreecommitdiffstats
path: root/src/include/stdlib.h
diff options
context:
space:
mode:
authorMichael Brown2007-06-11 22:36:10 +0200
committerMichael Brown2007-06-11 22:36:10 +0200
commit058b20052914ee2b0ccff4a89b71a61bf9d29a27 (patch)
tree90163f360caf169a9ccf18c92e9f2e64a19ecf2c /src/include/stdlib.h
parentAdd missing call to free_iob(). (diff)
downloadipxe-058b20052914ee2b0ccff4a89b71a61bf9d29a27.tar.gz
ipxe-058b20052914ee2b0ccff4a89b71a61bf9d29a27.tar.xz
ipxe-058b20052914ee2b0ccff4a89b71a61bf9d29a27.zip
Renamed _calloc() to zalloc(), ready to be used as a standalone function.
Diffstat (limited to 'src/include/stdlib.h')
-rw-r--r--src/include/stdlib.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/stdlib.h b/src/include/stdlib.h
index 6a0e9163..5c8fc3df 100644
--- a/src/include/stdlib.h
+++ b/src/include/stdlib.h
@@ -23,7 +23,7 @@ extern unsigned long strtoul ( const char *p, char **endp, int base );
extern void * malloc ( size_t size );
extern void * realloc ( void *old_ptr, size_t new_size );
extern void free ( void *ptr );
-extern void * _calloc ( size_t len );
+extern void * zalloc ( size_t len );
/**
* Allocate cleared memory
@@ -35,11 +35,11 @@ extern void * _calloc ( size_t len );
* Allocate memory as per malloc(), and zero it.
*
* This is implemented as a static inline, with the body of the
* function in _calloc(), since in most cases @c nmemb will be 1 and
* doing the multiply is just wasteful.
*/
static inline void * calloc ( size_t nmemb, size_t size ) {
- return _calloc ( nmemb * size );
+ return zalloc ( nmemb * size );
}
/*****************************************************************************
@@ -35,11 +35,11 @@ extern void * _calloc ( size_t len );
*
* This is implemented as a static inline, with the body of the
- * function in _calloc(), since in most cases @c nmemb will be 1 and
+ * function in zalloc(), since in most cases @c nmemb will be 1 and
* doing the multiply is just wasteful.
*/